@@ -4,18 +4,23 @@
 //! [R3]: ::r3
 //! [RZ/A1H]: https://www.renesas.com/us/en/products/microcontrollers-microprocessors/rz/rza/rza1h.html
 //! [GR-PEACH]: https://www.renesas.com/us/en/products/gadget-renesas/boards/gr-peach.html
+#![feature(const_trait_impl)]
 #![feature(const_mut_refs)]
-#![feature(const_fn_fn_ptr_basics)]
-#![feature(const_fn_trait_bound)]
-#![feature(asm)]
+#![cfg_attr(
+    feature = "doc",
+    doc(html_logo_url = "https://r3-os.github.io/r3/logo-small.svg")
+)]
 #![deny(unsafe_op_in_unsafe_fn)]
-#![deny(unsupported_naked_functions)]
 #![no_std]
 
 /// Used by `use_os_timer!`
 #[doc(hidden)]
 pub extern crate r3;
 
+/// Used by `use_os_timer!`
+#[doc(hidden)]
+pub extern crate r3_kernel;
+
 /// Used by `use_os_timer!`
 #[doc(hidden)]
 pub extern crate r3_portkit;
